@@ -1,11 +1,8 @@
-use crate::{
-    fit::InsufficientWidthError,
-};
+use crate::fit::InsufficientWidthError;
 
 /// Termimad error type
 #[derive(thiserror::Error, Debug)]
 pub enum Error {
-
     #[error("IO error: {0}")]
     IO(#[from] std::io::Error),
 
