@@ -1,10 +1,8 @@
 use {
-    crate::crossterm::{
-        event::{
-            KeyCode,
-            KeyEvent,
-            KeyModifiers,
-        },
+    crate::crossterm::event::{
+        KeyCode,
+        KeyEvent,
+        KeyModifiers,
     },
     std::fmt,
 };
@@ -26,7 +24,12 @@ pub struct EscapeSequence {
 impl fmt::Display for EscapeSequence {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         for key in &self.keys {
-            if let KeyEvent { code: KeyCode::Char(c), modifiers: KeyModifiers::NONE, .. } = key {
+            if let KeyEvent {
+                code: KeyCode::Char(c),
+                modifiers: KeyModifiers::NONE,
+                ..
+            } = key
+            {
                 write!(f, "{}", c)?;
             }
         }
