@@ -311,7 +311,7 @@ impl MadSkin {
 
     /// return the style appliable to a given compound.
     /// It's a composition of the various appliable base styles.
-    fn compound_style(&self, line_style: &LineStyle, compound: &Compound<'_>) -> CompoundStyle {
+    pub fn compound_style(&self, line_style: &LineStyle, compound: &Compound<'_>) -> CompoundStyle {
         if *compound.src == *crate::fit::ELLIPSIS {
             return self.ellipsis.clone();
         }
@@ -403,6 +403,18 @@ impl MadSkin {
         print!("{}", fmt_text);
     }
 
+    /// do a `print!` of the given expander
+    pub fn write_expander<W: Write>(
+        &self,
+        w: &mut W,
+        expander: TextTemplateExpander<'_, '_>,
+    ) -> std::io::Result<()> {
+        let (width, _) = terminal_size();
+        let text = expander.expand();
+        let fmt_text = FmtText::from_text(self, text, Some(width as usize));
+        write!(w, "{}", fmt_text)
+    }
+
     /// do a `print!` of the given owning expander
     pub fn print_owning_expander(
         &self,
@@ -415,6 +427,19 @@ impl MadSkin {
         print!("{}", fmt_text);
     }
 
+    /// do a `print!` of the given owning expander
+    pub fn write_owning_expander<W: Write>(
+        &self,
+        w: &mut W,
+        expander: &OwningTemplateExpander<'_>,
+        template: &TextTemplate<'_>,
+    ) -> std::io::Result<()> {
+        let (width, _) = terminal_size();
+        let text = expander.expand(template);
+        let fmt_text = FmtText::from_text(self, text, Some(width as usize));
+        write!(w, "{}", fmt_text)
+    }
+
     /// do a `print!` of the given owning expander
     pub fn print_owning_expander_md<T: Into<String>>(
         &self,
@@ -429,6 +454,21 @@ impl MadSkin {
         print!("{}", fmt_text);
     }
 
+    /// do a `print!` of the given owning expander
+    pub fn write_owning_expander_md<T: Into<String>, W: Write>(
+        &self,
+        w: &mut W,
+        expander: &OwningTemplateExpander<'_>,
+        template: T,
+    ) -> std::io::Result<()> {
+        let (width, _) = terminal_size();
+        let template_md: String = template.into();
+        let template = TextTemplate::from(&*template_md);
+        let text = expander.expand(&template);
+        let fmt_text = FmtText::from_text(self, text, Some(width as usize));
+        write!( w, "{}", fmt_text)
+    }
+
     pub fn print_composite(&self, composite: Composite<'_>) {
         print!(
             "{}",
